package org.artifactory.queue.services;

import org.artifactory.queue.QueueConfiguration;
import org.artifactory.storage.db.event.entity.NodeEventCursorType;

/**
 * this service exposes helpful api calls to be used by application code
 *
 * @author Avishay Halpren
 */
public interface QueueService {

    /**
     * returns a QueueOperation (for a specific Queue) for a repoKey and type
     * (variant required only when registered in configuration)
     */
    QueueOperations getQueueOperations(String repoKey, NodeEventCursorType type, String variant);

    default QueueOperations getQueueOperations(String repoKey, NodeEventCursorType type) {
        return getQueueOperations(repoKey, type, "");
    }

    /**
     * register a QueueConfiguration for existing repoKey without using QueueConfigurationRegistrar
     */
    void register(String repoKey, QueueConfiguration configuration);

    /**
     * de-registration of a repoKey+type+variant (represents queue)
     * - removes the queue
     * - cancel triggered jobs
     * - deletes the marker of the queue
     */
    void deRegister(String repoKey, NodeEventCursorType type, String variant);

    /**
     * checks if repoKey+type+variant (queue) exist
     */
    boolean isRegistered(String repoKey, NodeEventCursorType type, String variant);
}
