package org.artifactory.version.converter.v312;

import org.artifactory.version.converter.XmlConverter;
import org.jdom2.Document;
import org.jdom2.Element;
import org.jdom2.Namespace;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.List;

import static org.artifactory.util.RepoLayoutUtils.CONAN_DEFAULT_NAME;

/**
 * @author volodymyrm
 */
public class FixConanDefaultLayoutConverter implements XmlConverter {
    private static final Logger log = LoggerFactory.getLogger(FixConanDefaultLayoutConverter.class);
    private static final int NAME_INDEX = 1;
    private static final int ARTIFACT_PATH_PATTERN_INDEX = 3;
    private static final String ARTIFACT_PATH_PATTERN_KEY = "artifactPathPattern";
    private static final String FIXED_PATH_PATTERN =
            "[org]/[module]/[baseRev]/[channel<[^/]+>]/[folderItegRev]/(package/[package_id<[^/]+>]/[fileItegRev]/)" +
                    "[remainder<(?:.+)>]";

    @Override
    public void convert(Document doc) {
        log.info("Starting 'Conan fix default repository layout' conversion");
        Element rootElement = doc.getRootElement();
        Namespace namespace = rootElement.getNamespace();

        Element repoLayoutsElement = rootElement.getChild("repoLayouts", namespace);
        List<Element> repoLayouts = repoLayoutsElement.getChildren();

        for (Element layout : repoLayouts) {
            if (layout.getContent() != null && layout.getContent().get(NAME_INDEX) != null
                    && CONAN_DEFAULT_NAME.equals(layout.getContent().get(NAME_INDEX).getValue())) {
                log.debug("Found conan-default layout");
                layout.setContent(ARTIFACT_PATH_PATTERN_INDEX, getFixedArtifactPathPattern(namespace));
                log.debug("Fixed conan-default layout successfully");
            }
        }
        log.info("Finished 'Conan fix default repository layout' conversion successfully");
    }

    private Element getFixedArtifactPathPattern(Namespace namespace) {
        Element artifactPathPatternElement = new Element(ARTIFACT_PATH_PATTERN_KEY, namespace);
        artifactPathPatternElement.setText(FIXED_PATH_PATTERN);
        return artifactPathPatternElement;
    }
}