package org.artifactory.ui.utils;

import org.artifactory.descriptor.repo.RepoType;
import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.Test;

import java.util.EnumSet;
import java.util.List;

import static org.artifactory.descriptor.repo.RepoType.Alpine;
import static org.artifactory.descriptor.repo.RepoType.Bower;
import static org.artifactory.descriptor.repo.RepoType.CRAN;
import static org.artifactory.descriptor.repo.RepoType.Cargo;
import static org.artifactory.descriptor.repo.RepoType.Chef;
import static org.artifactory.descriptor.repo.RepoType.CocoaPods;
import static org.artifactory.descriptor.repo.RepoType.Composer;
import static org.artifactory.descriptor.repo.RepoType.Conan;
import static org.artifactory.descriptor.repo.RepoType.Conda;
import static org.artifactory.descriptor.repo.RepoType.Debian;
import static org.artifactory.descriptor.repo.RepoType.Gems;
import static org.artifactory.descriptor.repo.RepoType.Helm;
import static org.artifactory.descriptor.repo.RepoType.Npm;
import static org.artifactory.descriptor.repo.RepoType.NuGet;
import static org.artifactory.descriptor.repo.RepoType.Opkg;
import static org.artifactory.descriptor.repo.RepoType.Pub;
import static org.artifactory.descriptor.repo.RepoType.Puppet;
import static org.artifactory.descriptor.repo.RepoType.Pypi;
import static org.artifactory.descriptor.repo.RepoType.Swift;
import static org.artifactory.descriptor.repo.RepoType.Terraform;
import static org.artifactory.descriptor.repo.RepoType.YUM;

class ReindexUtilsTest {

    @Test
    void hasLocalReindex() {
        EnumSet<RepoType> localEnabled = EnumSet.copyOf(
                List.of(Gems, Npm, Bower, CocoaPods, NuGet, Debian, Opkg, YUM, Pypi, Composer, Chef, Puppet, Helm, CRAN,
                        Conda, Conan, Alpine, Cargo, Swift, Pub, Terraform));
        EnumSet<RepoType> localDisabled = EnumSet.complementOf(localEnabled);
        localEnabled.forEach(repo -> Assertions.assertTrue(ReindexUtils.hasLocalReindex(repo)));
        localDisabled.forEach(repo -> Assertions.assertFalse(ReindexUtils.hasLocalReindex(repo)));
    }

    @Test
    void hasRemoteReindex() {
        EnumSet<RepoType> remoteEnabled = EnumSet.copyOf(List.of(Bower, NuGet, Cargo));
        EnumSet<RepoType> remoteDisabled = EnumSet.complementOf(remoteEnabled);
        remoteEnabled.forEach(repo -> Assertions.assertTrue(ReindexUtils.hasRemoteReindex(repo)));
        remoteDisabled.forEach(repo -> Assertions.assertFalse(ReindexUtils.hasRemoteReindex(repo)));
    }

    @Test
    void hasVirtualReindex() {
        EnumSet<RepoType> virtualEnabled = EnumSet.copyOf(List.of(Gems, Npm, Bower, NuGet, Debian));
        EnumSet<RepoType> virtualDisabled = EnumSet.complementOf(virtualEnabled);
        virtualEnabled.forEach(repo -> Assertions.assertTrue(ReindexUtils.hasVirtualReindex(repo)));
        virtualDisabled.forEach(repo -> Assertions.assertFalse(ReindexUtils.hasVirtualReindex(repo)));
    }
}