package org.artifactory.rest.filter;

import java.lang.annotation.Documented;
import java.lang.annotation.Retention;
import java.lang.annotation.Target;

import static java.lang.annotation.ElementType.METHOD;
import static java.lang.annotation.ElementType.TYPE;
import static java.lang.annotation.RetentionPolicy.RUNTIME;

/**
 * Marks a resource as accessible via a scoped access token. Its value is an allowed permission scope
 * string in the following format: {@code <resource-type>:<target>[/<sub-resource>]:<actions>}.<br/><br/>
 *
 * NOTE: if used together with <code>@RolesAllowed</code> annotation then a resource will be accessible
 * if the access token has a valid scope OR the role is allowed.
 * See <code>org.artifactory.rest.filter.AllowedPermissionScopeDynamicFeature</code> for details.
 *
 * @author Oleksandr Legenkiy
 */
@Documented
@Retention(RUNTIME)
@Target({TYPE, METHOD})
public @interface AllowedPermissionScope {

    /**
     * The allowed permission scope
     */
    String value();
}
