package org.artifactory.rest.services.permissions;

import org.artifactory.build.BuildNameAndRepo;
import org.artifactory.build.InternalBuildService;
import org.artifactory.rest.common.service.security.permissions.RestSecurityRequestHandlerV2;
import org.testng.annotations.Test;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

import static org.mockito.ArgumentMatchers.any;
import static org.mockito.Mockito.mock;
import static org.mockito.Mockito.when;
import static org.testng.Assert.assertEquals;
import static org.testng.Assert.assertNotNull;

/**
 * @author Oleksandr Legenkiy
 */
public class RestSecurityRequestHandlerV2ImplTest {

    @Test
    public void testGetBuildsPerPatternsWithSpecialChars() {
        InternalBuildService buildServiceMock = mock(InternalBuildService.class);
        List<BuildNameAndRepo> builds = new ArrayList<>();
        builds.add(new BuildNameAndRepo("%SOME?/_Build!.", "someRepo"));
        builds.add(new BuildNameAndRepo("%S*ME?/_ot her%build!.", "someRepo"));
        when(buildServiceMock.getBuildsInfoInternally(any())).thenReturn(builds);

        RestSecurityRequestHandlerV2 requestHandler =
                new RestSecurityRequestHandlerV2Impl(null, null, null, null, buildServiceMock, null, null, null);

        List<String> includePatterns = Collections.singletonList("%S*ME?/_ot her%build!./**");
        List<String> excludePatterns = Collections.singletonList("%SOME?/_Build!./**");
        List<String> results = requestHandler.getBuildsPerPatterns(includePatterns, excludePatterns, "buildRepo");

        assertNotNull(results);
        assertEquals(results.size(), 1);
        assertEquals(results.get(0), "%S*ME?/_ot her%build!.");
    }
}
